@@ -1,4 +1,5 @@
 import os
+import sys
 
 import nox
 
@@ -15,6 +16,11 @@ def test(session):
     session.env["YARL_NO_EXTENSIONS"] = "1"
     session.env["FROZENLIST_NO_EXTENSIONS"] = "1"
 
+    # This would need to be updated if we added PyPy
+    # to our default Python versions above. Right now
+    # PyPy is only used on CI.
+    pypy = session.python is None and sys.implementation.name == "pypy"
+
     session.install("-rdev-requirements.txt", ".")
     session.run("pip", "freeze")
     session.run(
@@ -23,6 +29,7 @@ def test(session):
         "-s",
         "-rs",
         "--no-flaky-report",
+        *(("--config-file=pypy-pytest.ini",) if pypy else ()),
         "--max-runs=3",
         *(session.posargs or ("tests/",)),
     )
